@@ -255,6 +255,15 @@ public abstract class A3Object {
         setLoc(new Vector3d(x,y,z));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ位置に座標をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setLoc(A3Object a) {
+        setLoc(a.getLoc());
+    }
+
     /**
      * 位置を即座にセットするためのメソッド。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -271,6 +280,14 @@ public abstract class A3Object {
         setLocImmediately(new Vector3d(x,y,z));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ位置に座標を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setLocImmediately(A3Object a) {
+        setLocImmediately(a.getLoc());
+    }
+
     /**
      * 現在位置に引数で与えたベクトルを加えて新しい現在位置をセットするためのメソッド。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -339,6 +356,16 @@ public abstract class A3Object {
         setQuat(new Quat4d(x,y,z,w));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ向きに回転をセットするための
+     * メソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setQuat(A3Object a) {
+        setQuat(a.getQuat());
+    }
+
     /**
      * 回転を即座にセットするためのメソッド(四元数:Quad4d版)。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -355,6 +382,15 @@ public abstract class A3Object {
         setQuatImmediately(new Quat4d(x,y,z,w));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ向きに回転を即座にセットするための
+     * メソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setQuatImmediately(A3Object a) {
+        setQuatImmediately(a.getQuat());
+    }
+
     /**
      * 現在の回転に引数で与えた回転を合成するメソッド(四元数:Quat4d版)。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -528,6 +564,16 @@ public abstract class A3Object {
         setQuat(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ向きに
+     * 回転をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setRev(A3Object a) {
+        setQuat(a.getQuat());
+    }
+
     /**
      * 回転を即座にセットするためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -548,6 +594,15 @@ public abstract class A3Object {
         setQuatImmediately(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ向きに
+     * 回転を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setRevImmediately(A3Object a) {
+        setQuatImmediately(a.getQuat());
+    }
+
     /**
      * 現在の回転に引数の回転を合成するためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -681,6 +736,16 @@ public abstract class A3Object {
         behavior.setScale(s);
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ
+     * 拡大率をセットするためのメソッド。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setScale(A3Object a) {
+        behavior.setScale(a.getScale());
+    }
+
     /**
      * 拡大率を即時にセットするためのメソッド。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -689,6 +754,15 @@ public abstract class A3Object {
         behavior.setScaleImmediately(s);
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ
+     * 拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleImmediately(A3Object a) {
+        behavior.setScaleImmediately(a.getScale());
+    }
+
     /**
      * 現在の拡大率に引数の数値をかけてセットするためのメソッド。
      * behaviorが有効であれば、補完機能が働き変更はなめらかに
@@ -1166,6 +1240,34 @@ public abstract class A3Object {
         behavior.rollLeftNow(deg);
     }
 
+    /**
+     * 方向ベクトルのX,Y,Z成分を指定して，そちらを向くように回転します。
+     */
+    public void turnTo(double dirX, double dirY, double dirZ) {
+        behavior.turnTo(dirX,dirY,dirZ);
+    }
+
+    /**
+     * 方向ベクトルを指定して，そちらを向くように回転します。
+     */
+    public void turnTo(Vector3d dir) {
+        behavior.turnTo(dir);
+    }
+
+    /**
+     * 方向ベクトルのX,Y,Z成分を指定して，そちらを向くように即時に回転します。
+     */
+    public void turnToNow(double dirX, double dirY, double dirZ) {
+        behavior.turnToNow(dirX,dirY,dirZ);
+    }
+
+    /**
+     * 方向ベクトルを指定して，そちらを向くように即時に回転します。
+     */
+    public void turnToNow(Vector3d dir) {
+        behavior.turnToNow(dir);
+    }
+
     /**
      * このオブジェクトのローカルな座標系のX軸がグローバルな
      * 仮想空間の座標系ではどちらの方向になるのかを返します。
@@ -1190,6 +1292,29 @@ public abstract class A3Object {
         return behavior.getUnitVecZ();
     }
 
+    /**
+     * このオブジェクトの座標，回転，拡大縮小率を引数で
+     * 指定されたオブジェクトと一致させます。
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void setLocRevScale(A3Object a) {
+        behavior.setLoc(a.getLoc());
+        behavior.setQuat(a.getQuat());
+        behavior.setScale(a.getScale());
+    }
+
+    /**
+     * このオブジェクトの座標，回転，拡大縮小率を引数で
+     * 指定されたオブジェクトと即座に一致させます。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setLocRevScaleNow(A3Object a) {
+        behavior.setLocImmediately(a.getLoc());
+        behavior.setQuatImmediately(a.getQuat());
+        behavior.setScaleImmediately(a.getScale());
+    }
+
     /**
      * このオブジェクトのリソースを開放します。
      */
@@ -1480,6 +1605,14 @@ public abstract class A3Object {
         setLocImmediately(new Vector3d(x,y,z));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ位置に座標を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setLocNow(A3Object a) {
+        setLocImmediately(a.getLoc());
+    }
+
     /**
      * 現在位置に引数で与えたベクトルを加えて新しい現在位置を即座にセットするためのメソッド。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -1512,6 +1645,15 @@ public abstract class A3Object {
         setQuatImmediately(new Quat4d(x,y,z,w));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ向きに回転を即座にセットするための
+     * メソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setQuatNow(A3Object a) {
+        setQuatImmediately(a.getQuat());
+    }
+
     /**
      * 現在の回転に引数で与えた回転を即座に合成するメソッド(四元数:Quad4d版)。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -1588,6 +1730,15 @@ public abstract class A3Object {
         setQuatImmediately(Util.euler2quat(x*Math.PI/180.0,y*Math.PI/180.0,z*Math.PI/180.0));
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ向きに
+     * 回転を即座にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setRevNow(A3Object a) {
+        setQuatImmediately(a.getQuat());
+    }
+
     /**
      * 現在の回転に引数の回転を即座に合成するためのメソッド(オイラー角をデグリーで指定:Vector3d版)。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
@@ -1647,6 +1798,15 @@ public abstract class A3Object {
         behavior.setScaleImmediately(s);
     }
 
+    /**
+     * 引数で指定されたA3Objectと同じ
+     * 拡大率を即時にセットするためのメソッド。
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void setScaleNow(A3Object a) {
+        behavior.setScaleImmediately(a.getScale());
+    }
+
     /**
      * 現在の拡大率に引数の数値をかけて即座にセットするためのメソッド。
      * behaviorが有効であってもなくても、変更が即座に反映されます。
