@@ -1800,4 +1800,138 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
     public void rollCameraLeftNow(double deg,int scene) {
         universe.rollCameraLeftNow(deg,scene);
     }
+    //****************************************
+    @Override
+    public void setCameraLookAtPoint(A3Object a) {
+        universe.setCameraLookAtPoint(a);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,Vector3d up) {
+        universe.setCameraLookAtPoint(a,up);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,int scene) {
+        universe.setCameraLookAtPoint(a,scene);
+    }
+    @Override
+    public void setCameraLookAtPoint(A3Object a,Vector3d up,int scene) {
+        universe.setCameraLookAtPoint(a,up,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a) {
+        universe.setCameraLookAtPointNow(a);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up) {
+        universe.setCameraLookAtPointNow(a,up);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,int scene) {
+        universe.setCameraLookAtPointNow(a,scene);
+    }
+    @Override
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up,int scene) {
+        universe.setCameraLookAtPointNow(a,up);
+    }
+    @Override
+    public ArrayList<A3Object> getAll() {
+        return universe.getAll();
+    }
+    @Override
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c) {
+        return universe.getAll(c);
+    }
+    @Override
+    public ArrayList<A3Object> getAll(int scene) {
+        return universe.getAll(scene);
+    }
+    @Override
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c,int scene) {
+        return universe.getAll(c,scene);
+    }
+//-------
+    @Override
+    public void turnCameraTo(double dirX,double dirY,double dirZ) {
+        universe.turnCameraTo(dirX,dirY,dirZ);
+    }
+    @Override
+    public void turnCameraTo(Vector3d dir) {
+        universe.turnCameraTo(dir);
+    }
+    @Override
+    public void turnCameraToNow(double dirX,double dirY,double dirZ) {
+        universe.turnCameraToNow(dirX,dirY,dirZ);
+    }
+    @Override
+    public void turnCameraToNow(Vector3d dir) {
+        universe.turnCameraToNow(dir);
+    }
+    @Override
+    public void turnCameraTo(double dirX,double dirY,double dirZ,int scene) {
+        universe.turnCameraTo(dirX,dirY,dirZ,scene);
+    }
+    @Override
+    public void turnCameraTo(Vector3d dir,int scene) {
+        universe.turnCameraTo(dir,scene);
+    }
+    @Override
+    public void turnCameraToNow(double dirX,double dirY,double dirZ,int scene) {
+        universe.turnCameraToNow(dirX,dirY,dirZ,scene);
+    }
+    @Override
+    public void turnCameraToNow(Vector3d dir,int scene) {
+        universe.turnCameraToNow(dir,scene);
+    }
+
+    //2015,12/06: 指定したA3Objectの情報をもとにカメラを
+    //コントロールするメソッド達
+    @Override public void setCameraLoc(A3Object a)
+    {setCameraLoc(a.getLoc());}
+    @Override public void setCameraQuat(A3Object a)
+    {setCameraQuat(a.getQuat());}
+    @Override public void setCameraRev(A3Object a)
+    {setCameraQuat(a.getQuat());}
+    @Override public void setCameraScale(A3Object a)
+    {setCameraScale(a.getScale());}
+    @Override public void setCameraLocRevScale(A3Object a)
+    {setCameraLoc(a.getLoc());
+     setCameraQuat(a.getQuat());
+     setCameraScale(a.getScale());}
+    @Override public void setCameraLocNow(A3Object a)
+    {setCameraLocNow(a.getLoc());}
+    @Override public void setCameraQuatNow(A3Object a)
+    {setCameraQuatNow(a.getQuat());}
+    @Override public void setCameraRevNow(A3Object a)
+    {setCameraQuatNow(a.getQuat());}
+    @Override public void setCameraScaleNow(A3Object a)
+    {setCameraScaleNow(a.getScale());}
+    @Override public void setCameraLocRevScaleNow(A3Object a)
+    {setCameraLocNow(a.getLoc());
+     setCameraQuatNow(a.getQuat());
+     setCameraScaleNow(a.getScale());}
+    @Override public void setCameraLoc(A3Object a,int scene)
+    {setCameraLoc(a.getLoc(),scene);}
+    @Override public void setCameraQuat(A3Object a,int scene)
+    {setCameraQuat(a.getQuat(),scene);}
+    @Override public void setCameraRev(A3Object a,int scene)
+    {setCameraQuat(a.getQuat(),scene);}
+    @Override public void setCameraScale(A3Object a,int scene)
+    {setCameraScale(a.getScale(),scene);}
+    @Override public void setCameraLocRevScale(A3Object a,int scene)
+    {setCameraLoc(a.getLoc(),scene);
+     setCameraQuat(a.getQuat(),scene);
+     setCameraScale(a.getScale(),scene);}
+    @Override public void setCameraLocNow(A3Object a,int scene)
+    {setCameraLocNow(a.getLoc(),scene);}
+    @Override public void setCameraQuatNow(A3Object a,int scene)
+    {setCameraQuatNow(a.getQuat(),scene);}
+    @Override public void setCameraRevNow(A3Object a,int scene)
+    {setCameraQuatNow(a.getQuat(),scene);}
+    @Override public void setCameraScaleNow(A3Object a,int scene)
+    {setCameraScaleNow(a.getScale(),scene);}
+    @Override public void setCameraLocRevScaleNow(A3Object a,int scene)
+    {setCameraLocNow(a.getLoc(),scene);
+     setCameraQuatNow(a.getQuat(),scene);
+     setCameraScaleNow(a.getScale(),scene);}
+
 }
