@@ -885,5 +885,55 @@ class Scene implements Component2DContainerInterface {
     public void rollCameraLeftNow(double deg) {
         mulCameraQuatImmediately(Util.euler2quat(0,0,deg/180.0*Math.PI));
     }
-
+    public void turnCameraTo(double dirX,double dirY,double dirZ) {
+        Vector3d dir = new Vector3d(dirX,dirY,dirZ);
+        turnCameraTo(dir);
+    }
+    public void turnCameraTo(Vector3d dir) {
+        Vector3d lookAtPoint = new Vector3d();
+        lookAtPoint.add(cameraNowV,dir);
+        setCameraLookAtPoint(lookAtPoint);
+    }
+    public void turnCameraToNow(double dirX,double dirY,double dirZ) {
+        Vector3d dir = new Vector3d(dirX,dirY,dirZ);
+        turnCameraToNow(dir);
+    }
+    public void turnCameraToNow(Vector3d dir) {
+        Vector3d lookAtPoint = new Vector3d();
+        lookAtPoint.add(cameraNowV,dir);
+        setCameraLookAtPointImmediately(lookAtPoint);
+    }
+    
+    //****************************************
+    public void setCameraLookAtPoint(A3Object a) {
+        this.setCameraLookAtPoint(a.getLoc());
+    }
+    public void setCameraLookAtPoint(A3Object a,Vector3d up) {
+        this.setCameraLookAtPoint(a.getLoc(),up);
+    }
+    public void setCameraLookAtPointNow(A3Object a) {
+        this.setCameraLookAtPointImmediately(a.getLoc());
+    }
+    public void setCameraLookAtPointNow(A3Object a,Vector3d up) {
+        this.setCameraLookAtPointImmediately(a.getLoc(),up);
+    }
+    public ArrayList<A3Object> getAll() {
+        ArrayList<A3Object> ret;
+        synchronized(a3Hash) {
+            ret = new ArrayList<A3Object>(a3Hash.keySet());
+        }
+        return ret;
+    }
+    public ArrayList<A3Object> getAll(Class<? extends A3Object> c) {
+        ArrayList<A3Object> ret;
+        ArrayList<A3Object> ret2 = new ArrayList<A3Object>();
+        synchronized(a3Hash) {
+            ret = new ArrayList<A3Object>(a3Hash.keySet());
+        }
+        for (A3Object o:ret) {
+            if (c.isInstance(o))
+                ret2.add(o);
+        }
+        return ret2;
+    }
 }
