@@ -1,7 +1,5 @@
 package jp.sourceforge.acerola3d.a3;
 
-import java.util.ArrayList;
-
 import javax.vecmath.*;
 
 /**
@@ -26,7 +24,7 @@ public class Skeleton extends A3Object {
      * A3InitDataをもとにSkeletonオブジェクトを生成するコンストラクタ。
      * A3InitDataの引数の数は、3か4か5でなければなりません。
      * 
-     * <table border="1">
+     * <table border="1" summary="required data in A3InitData">
      * <tr><td>0:String  </td><td>BVHのURL      </td><td>必須</td></tr>
      * <tr><td>1:boolean </td><td>defaultPose   </td><td>必須</td></tr>
      * <tr><td>2:boolean </td><td>pause         </td><td>必須</td></tr>
@@ -137,7 +135,7 @@ public class Skeleton extends A3Object {
      *
      * A3UpdateDataにセットするデータは以下のようになります。
      *
-     * <table border="1">
+     * <table border="1" summary="required data in A3UpdateData">
      * <tr><td>0:boolean </td><td>defaultPose     </td><td>必須</td></tr>
      * <tr><td>1:boolean </td><td>pause           </td><td>必須</td></tr>
      * <tr><td>2:double  </td><td>pauseTime       </td><td>任意</td></tr>
