@@ -1,6 +1,6 @@
 package jp.sourceforge.acerola3d.sound;
 
-import net.java.games.joal.*;
+import com.jogamp.openal.*;
 import javax.vecmath.*;
 import javax.sound.sampled.*;
 import java.io.*;
@@ -69,6 +69,8 @@ public class LongSound implements A3Sound {
         inputBytes = baos.toByteArray();
     }
     void initBuffer2() throws Exception {
+        if (soundSystem.al==null) return;
+
         ByteArrayInputStream bais = new ByteArrayInputStream(inputBytes);
 
         ais = AudioSystem.getAudioInputStream(bais);
@@ -96,6 +98,7 @@ public class LongSound implements A3Sound {
         soundSystem.al.alGenBuffers(NUM_BUFFERS,buffers,0); check(1);
     }
     void initSource() {
+        if (soundSystem.al==null) return;
         soundSystem.al.alGenSources(1,source,0); check(2);
         sourceInit=true;
 
@@ -178,6 +181,7 @@ public class LongSound implements A3Sound {
         }
     }
     public void stop() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             return;
         stopRequest = true;
@@ -188,12 +192,14 @@ public class LongSound implements A3Sound {
         resetStream();
     }
     public void pause() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             return;
         stopRequest = true;
         soundSystem.al.alSourcePause(source[0]);
     }
     public void rewind() {
+        if (soundSystem.al==null) return;
         //とりあえずstop()と同じでいいんじゃね．
         if (!alIsSource())
             return;
@@ -205,6 +211,7 @@ public class LongSound implements A3Sound {
         resetStream();
     }
     public void setLoc(float x,float y,float z) {
+        if (soundSystem.al==null) return;
         if (type!=A3SoundType.BackgroundSound) {
             loc.set(x,y,z);
             if (alIsSource()) {
@@ -226,6 +233,7 @@ public class LongSound implements A3Sound {
         setQuat(q);
     }
     public void setQuat(Quat4d q) {
+        if (soundSystem.al==null) return;
         if (type!=A3SoundType.BackgroundSound) {
             quat.set(q);
             Vector3d v = Util.trans(q,new Vector3d(orgDir));
@@ -237,6 +245,7 @@ public class LongSound implements A3Sound {
     public void setVel() {
     }
     public void setGain(float g) {
+        if (soundSystem.al==null) return;
         gain = g;
         if (alIsSource())
             soundSystem.al.alSourcef(source[0],AL.AL_GAIN,g);
@@ -245,6 +254,7 @@ public class LongSound implements A3Sound {
         return gain;
     }
     public void setDirection(float x,float y,float z) {
+        if (soundSystem.al==null) return;
         orgDir.set(x,y,z);
         Vector3d v = Util.trans(quat,new Vector3d(orgDir));
         dir.set(v);
@@ -255,6 +265,7 @@ public class LongSound implements A3Sound {
         setDirection((float)d.x,(float)d.y,(float)d.z);
     }
     public void setOffset(float x,float y,float z) {
+        if (soundSystem.al==null) return;
         offset.set(x,y,z);
         if (alIsSource()) {
             Vector3d v = Util.trans(quat,new Vector3d(offset));
@@ -269,6 +280,7 @@ public class LongSound implements A3Sound {
         loop = l;
     }
     public void cleanUp() {
+        if (soundSystem.al==null) return;
         soundSystem.al.alSourceStop(source[0]);
         empty();
         soundSystem.al.alDeleteSources(1,source,0);
@@ -279,6 +291,7 @@ public class LongSound implements A3Sound {
         }
     }
     public void setType(A3SoundType t) {
+        if (soundSystem.al==null) return;
         type = t;
         if (!alIsSource())
             return;
